# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2020-05-01 12:07
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_notification', '0003_auto_20200429_1346'),
    ]

    operations = [
        migrations.AddField(
            model_name='notification',
            name='backlink_created',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
        migrations.AddField(
            model_name='subscription',
            name='backlink_created',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
    ]
